import { Router } from 'express';
import { IController } from './IController';
import { TRoute } from './TRoute';
export declare abstract class BaseController implements IController {
    readonly router: Router;
    /**
     * @return {void | Promise<void>}
     */
    initialize(): void | Promise<void>;
    /**
     * @param {TRoute} route
     * @return {TRouteObject}
     * @private
     */
    private unpackRoute;
    /**
     * @param {RouteHttpMethod} method
     * @param {string} path
     * @param {RouteHandler} handler
     * @param {e.Request} req
     * @param {e.Response} res
     * @param {e.NextFunction} next
     * @return {Promise<void>}
     * @private
     */
    private callHandler;
    /**
     * @param {e.Request} req
     * @param {e.Response} res
     * @param data
     * @return {never}
     * @private
     */
    private success;
    /**
     * @param {e.Request} req
     * @param {e.Response} res
     * @param {Error} error
     * @return {never}
     * @private
     */
    private error;
    /**
     * @return {TRoute[]}
     * @protected
     */
    protected abstract onInitializeRoutes(): TRoute[];
    /**
     * @param data
     * @return {any}
     * @protected
     */
    protected onTransformSuccessResponse(data: any): any;
    /**
     * @param {Error} error
     * @return {any}
     * @protected
     */
    protected onTransformErrorResponse(error: Error): any;
}
